OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bonvolu elekti dosieron.",
    "File is too big" : "Dosiero tro grandas",
    "The selected file is not an image." : "La elektita dosiero ne estas bildo.",
    "The selected file cannot be read." : "La elektita dosiero ne estas legebla.",
    "Invalid file provided" : "Nevalida dosiero provizita",
    "No image or file provided" : "Neniu bildo aŭ dosiero provizita",
    "Unknown filetype" : "Nekonata dosiertipo",
    "Invalid image" : "Nevalida bildo",
    "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
    "No temporary profile picture available, try again" : "Neniu provizora profilbildo disponeblas, bv. reprovi",
    "No crop data provided" : "Neniu stucdatumo provizita",
    "No valid crop data provided" : "Neniu valida stucdatumo provizita",
    "Crop is not square" : "Stuca elekto ne estas kvadrata",
    "State token does not match" : "Stata ĵetono ne kongruas",
    "Could not complete login" : "Ensaluto ne eblis",
    "Your login token is invalid or has expired" : "Via ensaluta ĵetono ne validas aŭ senvalidiĝis",
    "Password reset is disabled" : "Pasvorta restarigo malebligita",
    "Couldn't reset password because the token is invalid" : "Ne eblis restarigi pasvorton, ĉar la ĵetono ne validas",
    "Couldn't reset password because the token is expired" : "Ne eblis restarigi pasvorton, ĉar la ĵetono senvalidiĝis",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ne eblas sendi retpoŝton ĉar ne estas retpoŝtadreso por ĉi tiu uzantnomo. Bonvolu kontakti vian administranton.",
    "%s password reset" : "Restarigo de pasvorto %s",
    "Password reset" : "Restarigi pasvorton",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan butonon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan ligilon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
    "Reset your password" : "Restarigi vian pasvorton ",
    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi retpoŝton pri restarigo. Bonvolu kontakti vian administranton.",
    "Couldn't send reset email. Please make sure your username is correct." : "Ne eblis sendi la retmesaĝon por restarigi pasvorton. Bonvolu kontroli, ĉu via uzantnomo ĝustas.",
    "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
    "Preparing update" : "Preparante la ĝisdatigon",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Ripara stadio:",
    "Repair info:" : "Ripara informo:",
    "Repair warning:" : "Ripara averto:",
    "Repair error:" : "Ripara eraro:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Bv. uzi komandlinian ĝisdatigilon, ĉar aŭtomata ĝisdatigo estas malebligita en la dosiero „config.php“.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: kontrolante tabelon %s ",
    "Turned on maintenance mode" : "Reĝimo de prizorgado ŝaltita.",
    "Turned off maintenance mode" : "Reĝimo de prizorgado malŝaltita.",
    "Maintenance mode is kept active" : "Reĝimo de prizorgado pluas",
    "Updating database schema" : "Ĝisdatigante la skemon de la datumbazo",
    "Updated database" : "Ĝisdatiĝis datumbazo",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontrolante, ĉu la skemo de la datumbazo estas ĝisdatigebla (tio povas daŭri longe laŭ la grando de la datumbazo)",
    "Checked database schema update" : "Ĝisdatigo de la skemo de la datumbazo kontrolita",
    "Checking updates of apps" : "Kontrolante ĝisdatigojn de aplikaĵoj",
    "Checking for update of app \"%s\" in appstore" : "Kontrolante ĝisdatigon de la aplikaĵo „%s“ en aplikaĵejo",
    "Update app \"%s\" from appstore" : "Ĝisdatigon de la aplikaĵo „%s“ el aplikaĵejo",
    "Checked for update of app \"%s\" in appstore" : "Ĝisdatigo de la aplikaĵo „%s“ en aplikaĵejo kontrolita",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrolante, ĉu la skemo de la datumbazo por %s estas ĝisdatigebla (tio povas daŭri longe laŭ la grando de la datumbazo)",
    "Checked database schema update for apps" : "Ĝisdatigo de la skemo de la datumbazo por la aplikaĵoj kontrolita",
    "Updated \"%1$s\" to %2$s" : "„%1$s“ ĝisdatigita al %2$s",
    "Set log level to debug" : "Agordi la protokolnivelon je sencimigo",
    "Reset log level" : "Restarigi nivelon de protokolado",
    "Starting code integrity check" : "Kontrolante kodan integrecon",
    "Finished code integrity check" : "Fino de la kontrolo de koda integreco",
    "%s (incompatible)" : "%s (nekongrua)",
    "Following apps have been disabled: %s" : "Jenaj aplikaĵoj estis malŝaltataj: %s",
    "Already up to date" : "Jam aktuala",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezbona pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Via retservilo ankoraŭ ne estas agordita por permesi sinkronigon de dosieroj, ĉar la WebDAV-interfaco ŝajne difektiĝas.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Via retservilo ne estas agordita por trovi la adreson „{url}“. Pli da informo troveblas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Via retservilo ne estas agordita por trovi la adreson „{url}“. Tio plej verŝajne estas kaŭzita de servilo ne ĝisdatigita por rekte liveri tiun ĉi dosierujon. Bv. kompari vian agordon al transformreguloj en „.htaccess“ por Apache, aŭ la reguloj por Nginx en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>. Ĉe Nginx, tio, kio devas ĝisdatiĝi estas kutime linioj komencantaj per „location ~“.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Via retservilo ne estas agordita por sendi .woff2-dosierojn. Tio estas tipe problemo kun la agordo de Nginx. Nextcloud 15 bezonas adapton por ankaŭ sendi .woff2-dosierojn. Komparu vian Nginx-agordon kun la rekomendita agordo en nia <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ŝajnas ne esti taŭge agordita por informpeti sistemajn medivariablojn. La testado kun getenv(\"PATH\") revenigas nur malplenan respondon.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Bv. legi la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">instal-dokumentaron ↗</a> pri agordo-notoj pri PHP kaj pri PHP-agordo de via retservilo, precipe kiam vi uzas la modulon „php-fpm“.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La nurlega agordodosiero estis ebligita. Tio baras modifon de kelkaj agordoj per la reta fasado. Plie, la dosiero bezonos esti markita mane kiel legebla dum ĉiu ĝisdatigo.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Via datumbazo ne uzas la nivelon de izoltransakcio „READ COMMITTED“ (angle por „asertita datumlegado“). Tio povas estigi problemojn, kiam pluraj agoj ruliĝas paralele.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "La PHP-modulo „fileinfo“ mankas. Oni rekomendas ebligi tiun modulon por havi la plej bonan malkovron de MIME-tipo.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "La transakcia ŝloso de dosieroj estas malebligita: tio povas estigi problemojn kun kunkura aliro. Ebligu „filelocking.enabled“ en la dosiero config.php por eviti tiajn problemojn. Bv. vidi la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaron ↗</a> por pli da informoj.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Se via instalaĵo ne estas en la radiko de la domajno kaj uzas la sisteman „cron“, problemoj povas estiĝi kun generado de adresoj (URL). Por eviti tion, bv. agordi la opcion „overwrite.cli.url“ en la dosiero „config.php“ por meti en ĝi la vojon al la retservila radiko (propono:  „{suggestedOverwriteCliURL}“).",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne eblis ruli la cron-taskon per komandlinia interfaco. La jenaj eraroj okazis:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "La lasta fona tasko ruliĝis {relativeTime}. Io ŝajne misfunkciis.",
    "Check the background job settings" : "Kontrolu la agordon pri fona rulado",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "La servilo ne havas funkciantan retkonekton. Pluraj finpunktoj ne atingeblis. Do, kelkaj elementoj kiel surmeto de ekstera konservejo, sciigoj pri ĝisdatigoj aŭ instalado de ekstera liveranto ne funkcios. Defora atingo de dosieroj kaj sendo de sciigaj retmesaĝoj eble ne funkcios. Starigu konekton el tiu servilo al interreto por uzi ĉiujn eblojn.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Neniu kaŝmemoro estas agordita. Por plibonigi rapidecon, bv. agordi iun „memcache“, se disponebla. Pli da informoj troviĝas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Neniu taŭga fonto de hazardo por PHP: tio estas tre malrekomendita pro sekuriga kialoj. Pli da informoj troviĝas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Vi uzas ĉi-momente la version {version} de PHP. Promociu vian PHP-version por profiti de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">sekurigaj kaj rapidecaj ĝisdatigoj de la PHP-grupo</a>, tuj kiam via distribuaĵo subtenos ĝin.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Vi uzas ĉi-momente la version 5.6 de PHP. La nuna ĉefa versio de Nextcloud estas la lasta, kiu uzeblos kun PHP versio 5.6. Estas rekomendita promocii al PHP versio 7.0 kaj pli por povi instali la version 14 de Nextcloud.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Aŭ la agordo pri la kapoj de inversa prokurilo ne ĝustas, aŭ vi aliras al Nextcloud per fidinda prokurilo. Se vi ne aliras al Nextcloud per fidinda prokurilo, tio estas sekuriga problemo, kaj tio ebligas atakanton mistifiki tiun IP-adreson, kiun Nextcloud ricevas. Pli da informoj troveblas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Kaŝmemorilo „Memcached“ uziĝas nun kiel disa kaŝmemoro, sed la neĝusta PHP-modulo „memcache“ estas instalita. \\OC\\Memcache\\Memcached subtenas nur la modulon nomitan „memcached“ kaj ne tiun nomitan „memcache“. Vidu la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">„memcached“-vikio pri ambaŭ moduloj</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Kelkaj dosieroj ne sukcese trairis la kontrolon pri integreco. Pli da informaj pri solvado de tiu problemo troveblas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaro</a>: <a href=\"{codeIntegrityDownloadEndpoint}\">Listo de nevalidaj dosieroj...</a>, <a href=\"{rescanEndpoint}\">Reekzameni („rescan“) dosierojn...</a>.",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "La PHP-modulo „OPcache“ ne estas ŝargita. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Por pli da rapideco, oni rekomendas</a> ŝargi ĝin en via PHP-instalaĵon.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "La PHP-modulo „OPcache“ ne estas taŭge agordita. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Por pli da rapideco, oni rekomendas</a> uzi la jenajn agordojn en la dosiero <code>php.ini</code>:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Via PHP ne subtenas la bibliotekon FreeType, kio provokos misfunkcion de profilbildo kaj de la agorda fasado.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Mankanta indekso „{indexName}“ en tabelo „{tableName}“.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "En tiu servilo mankas rekomenditaj PHP-moduloj. Por pli da rapideco kaj pli bona kongrueco, bv. instali ilin.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Mankas konverto al granda entjero (angle „big int“) en kelkaj kolumnoj de la datumbazo. Pro la ebla malrapideco ŝanĝi kolumntipoj en grandaj tabeloj, ili ne estis ŝanĝitaj aŭtomate. Vi povas ŝanĝi ilin mane, rulante komandlinie „occ db:convert-filecache-bigint“. Sed tio devas esti farita dum la servilo ne estas funkcianta. Por pli da detaloj, legu <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">la helpan paĝon pri tio</a>.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite estas la nuna datumbazo uzita de la servilo. Por grandaj instalaĵoj, ni rekomendas uzi alian tipon de datumbazo.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Tio estas precipe rekomendinda, kiam oni uzas la surtablan programon por sinkronigi la dosierojn.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Por strukture transmeti al alia datumbazo, uzu la komandlinia ilo „occ db:convert-type“, aŭ vidu la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaron ↗</a>.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Uzo de la interna PHP-poŝtilo ne plu estas subtenata. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Bv. ĝisdatigi viajn agordojn pri retpoŝtilo ↗<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "La PHP-memorlimo estas sub la rekomendita valoro de 512 MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Kelkaj aplikaĵ-dosierujoj apartenas al malsama uzanto ol tiu de la retservilo. Tio povas okazi, kiam aplikaĵoj estis instalita mane. Kontrolu la permesojn de la jenaj dosierujoj:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQL uziĝas kiel datumbazo, sed ĝi ne subtenas 4-bajtajn signojn. Por ke ĝi povu uzi 4-bajtajn signojn (kiel emoĝiojn) sen problemo kun dosiernomo aŭ komentoj i.a., oni rekomendas ŝalti subtenon por 4-bajtaj signoj en MySQL. Pli pliaj detaloj, vidu la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaron pri tio</a>.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Tiu Nextcloud-servilo uzas objektokonservejon bazitan sur S3 kiel ĉefkonservejo. La alŝutitaj dosieroj provizore konserviĝas en la servilo, kaj pro tio oni rekomendas havi liberan spacon je 50 GB en la PHP-a provizora dosierujo. Kontrolu la protokolojn por ĉiuj detaloj pri la dosiervojo kaj la libera spaco. Do, aŭ ŝanĝu la provizoran dosierujon en „php.ini“, aŭ liberigu spacon en tiu loko.",
    "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Via datumdosierujo kaj viaj dosieroj estas probable elirebla el la interreto. La dosiero „.htaccess“ ne funkcias. Ni tre rekomendas, ke vi agordu vian retservilon, por ke la dosierujo de datumoj („data“) estu ne alirebla aŭ ĝi estu movita ekster la dokumentradiko de la retservilo.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Tio estas eventuala risko pri sekureco aŭ privateco. Bv. ĝustigi tiun agordon laŭe.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Iuj trajtoj povus ne funkcii ĝuste. Bv. ĝustigi tiun agordon laŭe.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne enhavas „{expected}“. Tio estas eventuala risko pri sekureco aŭ privateco. Bv. ĝustigi tiun agordon laŭe.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "La HTTP-kapo „{header}“ ne egalas al „{val1}“, „{val2}“, „{val3}“, „{val4}“ aŭ „{val5}“. Tio povas nepermesite diskonigi referencantojn. Legu la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C-rekomendon ↗</a>.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "La HTTP-kapo „Strict-Transport-Security“ (angle por severa sekurigo de transporto, HSTS) ne egalas almenaŭ „{seconds}“ sekundojn. Por pli da sekureco, oni rekomendas ebligi HSTS-kapon kiel priskribita en la <a href=\"{docUrl}\" rel=\"noreferrer noopener\">praktikaj konsiloj pri sekurigo ↗</a>.",
    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Vi atingas tiun retejon per HTTP. Ni tre rekomendas agordi vian retservilon tiel, ke HTTPS uziĝu anstataŭe; vidu la <a href=\"{docUrl}\">praktikajn konsilojn pri sekurigo ↗</a>.",
    "Shared" : "Kunhavata",
    "Shared with" : "Kunhavigita kun",
    "Shared by" : "Kunhavigita de",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Choose a password for the public link or press the \"Enter\" key" : "Elektu pasvorton por la publika ligilo aŭ premu la enigan klavon",
    "Copied!" : "Kopiita!",
    "Copy link" : "Kopii ligilon",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "Copy" : "Kopii",
    "Unable to create a link share" : "Ne eblis krei kunhavo-ligilon",
    "Unable to toggle this option" : "Ne eblis baskuligi tiun opcion",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Link" : "Ligilo",
    "Hide download" : "Kaŝi elŝuton",
    "Password protection enforced" : "Pasvorta protekto efektiva",
    "Password protect" : "Protekti per pasvorto",
    "Password" : "Pasvorto",
    "Allow editing" : "Permesi redakton",
    "Email link to person" : "Retpoŝti la ligilon",
    "Send" : "Sendi",
    "Allow upload and editing" : "Permesi alŝuton kaj redakton",
    "Read only" : "Nurlega",
    "File drop (upload only)" : "Demeti dosieron (nur alŝuto)",
    "Expiration date enforced" : "Limdato efektiva",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "Note to recipient" : "Noto al ricevonto",
    "Unshare" : "Malkunhavigi",
    "Delete share link" : "Forigi kunhavo-ligilon",
    "Add another link" : "Aldoni plian ligilon",
    "Password protection for links is mandatory" : "Pasvorta protekto de ligiloj estas deviga",
    "Share to {name}" : "Kunhavigi al {name}",
    "Share link" : "Kunhavigi ligilon",
    "New share link" : "Nova kunhavo-ligilo",
    "Created on {time}" : "Kreita je {time}",
    "Password protect by Talk" : "Pasvorta protekto pere de „Talk“",
    "Could not unshare" : "Ne eblis malkunhavigi",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you and {circle} by {owner}" : "Kunhavigita kun vi kaj {circle} de {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Kunhavigita kun vi kaj la konversacio {conversation} de {owner}",
    "Shared with you in a conversation by {owner}" : "Kunhavigita kun vi en konversacio de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "Choose a password for the mail share" : "Elektu pasvorton por la retpoŝta kunhavigo",
    "group" : "grupo",
    "remote" : "fora",
    "remote group" : "fora grupo",
    "email" : "retpoŝtadreso",
    "conversation" : "konversacio",
    "shared by {sharer}" : "kunhavigita de {sharer}",
    "Can reshare" : "Eblas rekunhavigi",
    "Can edit" : "Povas redakti",
    "Can create" : "Povas krei",
    "Can change" : "Eblas ŝanĝi",
    "Can delete" : "Povas forigi",
    "Access control" : "Alirkontrolo",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} kunhavigis per ligilo",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Share details could not be loaded for this item." : "Kunhavaj detaloj pri ĉi tiu ero ne ŝargeblis.",
    "Search globally" : "Serĉi ĉie",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Aŭtomata kompletigo bezonas almenaŭ {count} signon","Aŭtomata kompletigo bezonas almenaŭ {count} signojn"],
    "This list is maybe truncated - please refine your search term to see more results." : "Eble mankas rezultoj: bv. pliprecizigi vian serĉon por vidi pli da rezultoj.",
    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
    "No users found for {search}" : "Neniu uzanto troviĝis por {search}",
    "An error occurred (\"{message}\"). Please try again" : "Eraro okazis („{message}“). Bonvolu provi ree.",
    "An error occurred. Please try again" : "Eraro okazis. Bonvolu provi ree",
    "Home" : "Hejmo",
    "Work" : "Laboro",
    "Other" : "Alia",
    "{sharee} (remote group)" : "{sharee} (fora grupo)",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Kunhavigi",
    "Name or email address..." : "Nomo aŭ retpoŝtadreso...",
    "Name or federated cloud ID..." : "Namo aŭ federnuba identigilo...",
    "Name, federated cloud ID or email address..." : "Nomo, federnuba identigilo aŭ retpoŝtadreso...",
    "Name..." : "Nomo...",
    "Error" : "Eraro",
    "Error removing share" : "Eraro dum forigo de kunhavigo",
    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
    "restricted" : "limigita",
    "invisible" : "nevidebla",
    "({scope})" : "({scope})",
    "Delete" : "Forigi",
    "Rename" : "Alinomi",
    "Collaborative tags" : "Kunlaboraj etikedoj",
    "No tags found" : "Neniu etikedo troviĝis ",
    "unknown text" : "nekonata teksto",
    "Hello world!" : "Saluton, mondo!",
    "sunny" : "suna",
    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
    "Hello {name}" : "Saluton {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
    "new" : "nova",
    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
    "Update to {version}" : "Ĝisdatigi al {version}",
    "An error occurred." : "Eraro okazis.",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
    "Continue to Nextcloud" : "Daŭrigi al Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["La ĝisdatigo sukcesis. Alidirektante vin al Nextcloud post %n sekundo.","La ĝisdatigo sukcesis. Alidirektante vin al Nextcloud post %n sekundoj."],
    "Searching other places" : "Serĉante en aliaj lokoj",
    "No search results in other folders for {tag}{filter}{endtag}" : "Neniu serĉ-rezultoj en aliaj dosierujoj por {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} serĉ-rezulto en alia dosierujo","{count} serĉ-rezultoj en aliaj dosierujoj"],
    "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
    "An internal error occurred." : "Interna servileraro okazis.",
    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
    "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
    "Log in" : "Ensaluti",
    "Logging in …" : "Ensaluti...",
    "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
    "User disabled" : "Uzanto malvalidigita",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
    "Reset password" : "Restarigi pasvorton",
    "Password can not be changed. Please contact your administrator." : "Pasvorto ne eblas esti ŝanĝita. Bonvolu kontakti vian administranton.",
    "Back to login" : "Antaŭen al ensaluto",
    "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
    "Settings" : "Agordo",
    "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
    "Search contacts …" : "Serĉi kontaktojn…",
    "No contacts found" : "Neniu kontakto troviĝis",
    "Show all contacts …" : "Montri ĉiujn kontaktojn",
    "Loading your contacts …" : "Ŝargante viajn kontaktojn...",
    "Looking for {term} …" : "Serĉo de {term}…",
    "No" : "Ne",
    "Yes" : "Jes",
    "No files in here" : "Neniu dosiero ĉi tie",
    "New folder" : "Nova dosierujo",
    "No more subfolders in here" : "Ne plu estas subdosierujo ĉi tie.",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "{newName} already exists" : "{newName} jam ekzistas",
    "Choose" : "Elekti",
    "Move" : "Movi",
    "Error loading file picker template: {error}" : "Eraro dum ŝargo de ŝablono pri dosier-elektilo: {error}",
    "OK" : "Akcepti",
    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {eraro}",
    "read-only" : "nurlega",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
    "One file conflict" : "Unu dosierkonflikto",
    "New Files" : "Novaj dosieroj",
    "Already existing files" : "Jam ekzistantaj dosieroj",
    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
    "Cancel" : "Nuligi",
    "Continue" : "Daŭrigi",
    "(all selected)" : "(ĉiuj elektitaj)",
    "({count} selected)" : "({count} elektitaj)",
    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
    "Pending" : "Pritraktota",
    "Copy to {folder}" : "Kopii al {folder}",
    "Move to {folder}" : "Movi al {folder}",
    "Saving..." : "Konservante...",
    "Authentication required" : "Aŭtentiĝo nepras",
    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
    "Confirm" : "Konfirmi",
    "Failed to authenticate, try again" : "Malsukcesis aŭtentigi, provu ree",
    "seconds ago" : "sekundoj antaŭe",
    "Connection to server lost" : "Konekto al servilo perdita",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
    "New in" : "Nova en",
    "View changelog" : "Vidi ŝanĝoprotokolon",
    "No action available" : "Neniu ago disponebla",
    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
    "Personal" : "Persona",
    "Users" : "Uzantoj",
    "Apps" : "Aplikaĵoj",
    "Admin" : "Administranto",
    "Help" : "Helpo",
    "Access forbidden" : "Aliro estas malpermesata",
    "File not found" : "Dosiero ne troviĝis",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "La dokumento ne troveblis en la servilo. Eble la kunhavigo estis forigita aŭ eksvalidiĝis?",
    "Back to %s" : "Antaŭen al %s",
    "Internal Server Error" : "Interna servileraro",
    "The server was unable to complete your request." : "La servilo ne eblis plenumi vian peton.",
    "If this happens again, please send the technical details below to the server administrator." : "Se tio denove okazos, bv. sendi la teĥnikajn detalojn ĉi-sube al la administranto de la servilo.",
    "More details can be found in the server log." : "Pli da detaloj troveblas en la servila protokolo.",
    "Technical details" : "Teĥnikaj detaloj",
    "Remote Address: %s" : "Fora adreso: %s",
    "Request ID: %s" : "Peta identigilo: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Kodo: %s",
    "Message: %s" : "Mesaĝo: %s",
    "File: %s" : "Dosiero: %s",
    "Line: %s" : "Linio: %s",
    "Trace" : "Spuro",
    "Security warning" : "Sekureca averto",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
    "Create an <strong>admin account</strong>" : "Krei <strong>administranto-konton</strong>",
    "Username" : "Uzantnomo",
    "Storage & database" : "Konservejo kaj datumbazo",
    "Data folder" : "Datuma dosierujo",
    "Configure the database" : "Agordi la datumbazon",
    "Only %s is available." : "Nur %s disponeblas.",
    "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
    "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
    "Database user" : "Datumbaza uzanto",
    "Database password" : "Datumbaza pasvorto",
    "Database name" : "Datumbaza nomo",
    "Database tablespace" : "Datumbaza tabelospaco",
    "Database host" : "Datumbaza gastigo",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
    "Performance warning" : "Rendimenta averto",
    "You chose SQLite as database." : "Vi elektis datumbazon „SQLite“.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite estu nur uzita por minimuma kaj programista servilo. Por produkta medio, ni rekomendas uzi alian tipon de datumbazo.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se vi uzas klientojn por sinkronigi dosierojn, oni ne rekomendas datumbazon SQLite.",
    "Finish setup" : "Fini la instalon",
    "Finishing …" : "Finante...",
    "Need help?" : "Ĉu necesas helpo?",
    "See the documentation" : "Vidi la dokumentaron",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Ŝajnas, ke vi provas reinstali vian Nextcloud. Sed la dosiero CAN_INSTALL (angle por „eblo instali“) mankas en via dosierujo „config“. Bv. krei dosieron CAN_INSTALL ene de via dosierujo „config“ por daŭrigi.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ne eblis forigi la dosieron „CAN_INSTALL“ el via dosierujo „config“. Bv. forigi ĝin permane.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tiu aplikaĵo bezonas Ĝavoskripton („Javascript“) por funkcii. Bonvolu {linkstart}ŝalti Ĝavoskripton{linkend} kaj poste reŝargi la paĝon.",
    "Get your own free account" : "Ekhavu vian propran senpagan konton",
    "Skip to main content" : "Iru al la ĉefa enhavo",
    "Skip to navigation of app" : "Iru al la aplikaĵa navigado",
    "More apps" : "Pli da aplikaĵoj",
    "More" : "Pli",
    "More apps menu" : "Menuo „Pli da aplikaĵoj“",
    "Search" : "Serĉi",
    "Reset search" : "Restarigi serĉon",
    "Contacts" : "Kontaktoj",
    "Contacts menu" : "Menuo de kontaktoj",
    "Settings menu" : "Menuo de agordo",
    "Confirm your password" : "Konfirmu vian pasvorton",
    "Connect to your account" : "Konekti al via konto",
    "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
    "App token" : "Aplikaĵa ĵetono",
    "Grant access" : "Doni alirpermeson",
    "Alternative log in using app token" : "Ensaluti alimaniere per aplikaĵa ĵetono",
    "Account access" : "Aliro al konto",
    "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s.",
    "Account connected" : "Konto konektita",
    "Your client should now be connected! You can close this window." : "Via kliento estas konektita! Vi povas fermi tiun fenestron.",
    "New password" : "Nova pasvorto",
    "New Password" : "Nova pasvorto",
    "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Two-factor authentication" : "Dufaza aŭtentigo",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Plibonigita sekurigo estas ebligita por via konto. Elektu duan fazon por aŭtentigo:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ne eblis ŝargi almenaŭ unu el viaj ebligitaj metodoj pri dufaza aŭtentigo. Bv. kontakti vian administranton.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Kontakti vian administranton por helpo.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Bv. daŭrigi por agordi ĝin.",
    "Set up two-factor authentication" : "Agordi dufazan aŭtentigon",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Uzu unu el viaj rezervkodoj por ensaluti, aŭ kontaktu vian administranton por helpo.",
    "Use backup code" : "Uzi rezervkodon",
    "Cancel log in" : "Nuligi ensaluton",
    "Setup two-factor authentication" : "Agordi dufazan aŭtentigon",
    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Plibonigita sekurigo estas devigata por via konto. Elektu provizanton agordotan:",
    "Error while validating your second factor" : "Eraro dum validigo de via dua fazo",
    "Access through untrusted domain" : "Aliro tra nefidinda domajno",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bv. kontakti vian administranton. Se vi estas administranto, modifu la agordon „trusted_domains“ (fidindaj domajnoj en la angla) en la dosiero config/config.php (estas ekzemplo en config.sample.php).",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pliaj informoj pri agordo de tio troveblas en la %1$sdokumentaro%2$s.",
    "App update required" : "Aplikaĵa ĝisdatigo nepras",
    "%1$s will be updated to version %2$s" : "%1$s ĝisdatiĝos al versio %2$s",
    "These apps will be updated:" : "La jenajn aplikaĵoj ĝisdatiĝos:",
    "These incompatible apps will be disabled:" : "La jenaj malkongruaj aplikaĵoj estos malŝaltataj:",
    "The theme %s has been disabled." : "La etoso %s estis malebligita.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bonvolu certiĝi, ke la datumbazo, la dosierujo de agordoj kaj la dosierujo de datumoj jam estis savkopiitaj antaŭ ol plui.",
    "Start update" : "Ekĝisdatigi",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Por eviti eltempiĝon ĉe grandaj instalaĵoj, vi povas anstataŭe ruli la jenan komandon en via instalo-dosierujo:",
    "Detailed logs" : "Detalaj protokoloj",
    "Update needed" : "Bezonas ĝisdatigi",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Bv. uzi la komandlinian ĝisdatigilon, ĉar vi havas pli da 50 uzantojn en tiu servilo.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaron</a> por helpo.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mi scias, ke, se mi daŭrigas la ĝisdatigon per la reteja fasado, estas risko, ke la peto eltempiĝos kaj okazigos perdon de datumoj. Sed, mi havas sekurkopion kaj scias, kiel restaŭri mian servilon okaze de paneo.",
    "Upgrade via web on my own risk" : "Ĝisdatigi per reteja fasado je mia risko",
    "Maintenance mode" : "Reĝimo de prizorgado",
    "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
    "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
    "Updated \"%s\" to %s" : "Ĝisdatiĝis „%s“ al %s",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Estis problemoj kun kontrolo de la koda integreco. Pli da informoj...</a> ",
    "Dismiss" : "Forsendi",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La ligilo por restarigi vian pasvorton estis sendita al via retpoŝtadreso. Se vi ne ricevas ĝin baldaŭ, vidu vian spamujon.<br>Se ĝi ne estas tie, pridemandu vian administranton.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Viaj dosieroj estas ĉifritaj. Ne estos eble rehavi viajn datumojn post la restarigo de via pasvorto.<br />Se vi ne tute certas pri krio fari, bonvolu pridemandi vian administranton, antaŭ ol daŭrigi. <br />Ĉu vi ja volas daŭrigi?",
    "I know what I'm doing" : "Mi scias, kion mi faras",
    "Sending email …" : "Sendante retpoŝton...",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} versio {version} estas instalita. Pro stabileco kaj rendimento, oni rekomendas ĝisdatigi {name} al pli freŝa versio.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ne legeblas de PHP, kio estas tre malrekomendinde pro sekurigaj kialoj. Pli da informoj troveblas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaron</a>.",
    "Copy URL" : "Kopii retadreson",
    "Enable" : "Aktivigi",
    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} kunhavigis per ligilo",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (remote)" : "{sharee} (fora)",
    "{sharee} (email)" : "{sharee} (retpoŝtadreso)",
    "{sharee} (conversation)" : "{sharee} (dialogo)",
    "The specified document has not been found on the server." : "La donita dokumento ne troveblis en la servilo.",
    "You can click here to return to %s." : "Vi povas alklaki ĉi tie por antaŭeniri al %s.",
    "SQLite will be used as database." : "SQLite uziĝos kiel datumbazo.",
    "For larger installations we recommend to choose a different database backend." : "Por pli grandaj instalaĵoj, ni rekomendas uzi alian tipon de datumbazo.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Kiam oni uzas la surtablan programon por sinkronigi la dosierojn, SQLite-uzo estas malrekomendita.",
    "Wrong password." : "Neĝusta pasvorto.",
    "Please log in before granting %s access to your %s account." : "Bv. unue ensaluti por doni al %s aliron al via konto %s.",
    "You are about to grant %s access to your %s account." : "Vi tuj donos permeson al %s aliri al via konto %s.",
    "Redirecting …" : "Alidirektante...",
    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Plibonigita sekurigo estas ebligita por via konto. Aŭtentigu duafaze.",
    "Further information how to configure this can be found in the %sdocumentation%s." : "Pliaj informoj pri agordo de tio troveblas en la %sdokumentaro%s.",
    "%s will be updated to version %s" : "%s ĝisdatiĝos al versio %s",
    "This page will refresh itself when the %s instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo %s redisponeblos.",
    "Thank you for your patience." : "Dankon pro via pacienco.",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La ligilo por restarigi vian pasvorton estis sendita al via retpoŝtadreso. Se vi ne ricevas ĝin baldaŭ, vidu vian spamujon.<br>Se ĝi ne estas tie, pridemandu vian administranton."
},
"nplurals=2; plural=(n != 1);");
